AuthBasic

Struct AuthBasic 

pub struct AuthBasic(pub (String, Option<String>));
Basic authentication extractor, containing an identifier as well as an optional password

This is enabled via the auth-basic feature

Example

Though this structure can be used like any other axum extractor, we recommend this pattern:

use axum_auth::AuthBasic;

/// Takes basic auth details and shows a message
async fn handler(AuthBasic((id, password)): AuthBasic) -> String {
    if let Some(password) = password {
        format!("User '{}' with password '{}'", id, password)
    } else {
        format!("User '{}' without password", id)
    }
}

Errors

There are a few errors which this extractor can make. By default, all invalid responses are 400 BAD REQUEST with one of these messages:

  • `Authorization` header could not be decoded – The header couldn’t be decoded, probably missing a colon
  • `Authorization` header must be for basic authentication – Someone tried to use bearer auth instead of basic auth
  • `Authorization` header is missing – The header was required but it wasn’t found
  • `Authorization` header contains invalid characters – The header couldn’t be processed because of invalid characters

Tuple Fields

0: (String, Option<String>)